The Real Python Feed Reader is a basic web feed reader that can download the latest Real Python tutorials from the Real Python feed.

For more information see the tutorial How to Publish an Open-Source Python Package to PyPI on Real Python.

This is just a hello world package
